@@ -42,15 +42,27 @@ constexpr uint32_t HASH_MASK = 0xFFFFFFFF; // only lower 32 bits.
 // 2 for debug. 16 is best for a release build.
 constexpr uint8_t DICT_REMAP_ENTRIES = 16;
 
-// Load factor = 1 - 0.5 ^ LOAD_FACTOR_BITS. 0.75 is the optimal value for release builds.
-constexpr uint8_t DICT_LOAD_FACTOR_BITS = 2;
+// 100 for size < 1 << DICT_THRESHOLD_BITS + DICT_THRESHOLD_BITS;
+// 75 for larger sizes
+// 25 for min load factor.
+constexpr int MIN_DICT_LOAD_FACTOR_100 = 25;
+constexpr int DICT_LOAD_FACTOR_100 = 75;
+
+// when space_distance is greater than SPACE_DISTANCE_THRESHOLD, double the size unless the load
+// factor is already lower than MIN_DICT_LOAD_FACTOR_100.
+constexpr int SPACE_DISTANCE_THRESHOLD = 32;
+
+// To ignore occasional faraway spaces. only when space_distance_samples are above
+// MIN_SPACE_DISTANCE_SAMPLES, we consider space_distance is not by chance.
+constexpr int MIN_SPACE_DISTANCE_SAMPLES = 128;
 
 // Default number of hash buckets in dictionary.  The dictionary will
 // increase the size of the hash table as needed.
 constexpr uint8_t DEFAULT_DICT_SIZE = 0;
 
-// When log2_buckets > DICT_THRESHOLD_BITS, DICT_LOAD_FACTOR_BITS becomes effective.
-// Basically if dict size < 2^DICT_THRESHOLD_BITS + n, we size up only if necessary.
+// When log2_buckets > DICT_THRESHOLD_BITS, DICT_LOAD_FACTOR_BITS becomes
+// effective.  Basically if dict size < 2^DICT_THRESHOLD_BITS +
+// DICT_THRESHOLD_BITS, we size up only if necessary.
 constexpr uint8_t DICT_THRESHOLD_BITS = 3;
 
 // The value of an iteration cookie is the bucket and offset within the
@@ -72,7 +84,11 @@ public:
 
 	// The size of the key. Less than 8 bytes we'll store directly in the entry, otherwise we'll
 	// store it as a pointer. This avoids extra allocations if we can help it.
-	uint16_t key_size = 0;
+	uint32_t key_size = 0;
+
+	// The maximum value of the key size above. This allows Dictionary to truncate keys before
+	// they get stored into an entry to avoid weird overflow errors.
+	static constexpr uint32_t MAX_KEY_SIZE = UINT32_MAX;
 
 	// Lower 4 bytes of the 8-byte hash, which is used to calculate the position in the table.
 	uint32_t hash = 0;
@@ -83,7 +99,7 @@ public:
 		char* key;
 		};
 
-	DictEntry(void* arg_key, int key_size = 0, hash_t hash = 0, void* value = nullptr,
+	DictEntry(void* arg_key, uint32_t key_size = 0, hash_t hash = 0, void* value = nullptr,
 	          int16_t d = TOO_FAR_TO_REACH, bool copy_key = false)
 		: distance(d), key_size(key_size), hash((uint32_t)hash), value(value)
 		{
@@ -139,7 +155,7 @@ public:
 
 	template <typename T> T GetValue() const { return static_cast<T>(value); }
 
-	bool Equal(const char* arg_key, int arg_key_size, hash_t arg_hash) const
+	bool Equal(const char* arg_key, uint32_t arg_key_size, hash_t arg_hash) const
 		{ // only 40-bit hash comparison.
 		return (0 == ((hash ^ arg_hash) & HASH_MASK)) && key_size == arg_key_size &&
 		       0 == memcmp(GetKey(), arg_key, key_size);
@@ -279,7 +295,7 @@ public:
 	// manage as needed.
 	// If iterators_invalidated is supplied, its value is set to true
 	// if the removal may have invalidated any existing iterators.
-	void* Insert(void* key, int key_size, detail::hash_t hash, void* val, bool copy_key,
+	void* Insert(void* key, uint64_t key_size, detail::hash_t hash, void* val, bool copy_key,
 	             bool* iterators_invalidated = nullptr);
 
 	// Removes the given element.  Returns a pointer to the element in
@@ -532,6 +548,10 @@ private:
 	int max_entries = 0;
 	uint64_t cum_entries = 0;
 
+	uint32_t space_distance_samples = 0;
+	// how far the space is
+	int64_t space_distance_sum = 0;
+
 	dict_delete_func delete_func = nullptr;
 	detail::DictEntry* table = nullptr;
 	std::vector<IterCookie*>* cookies = nullptr;
