@@ -2,21 +2,37 @@
 
 #pragma once
 
-#include <sys/types.h> // for u_char
 #include <broker/expected.hh>
+#if ( OPENSSL_VERSION_NUMBER < 0x30000000L ) || defined(LIBRESSL_VERSION_NUMBER)
+#include <openssl/md5.h>
+#endif
 #include <paraglob/paraglob.h>
+#include <sys/types.h> // for u_char
 
 #include "zeek/IntrusivePtr.h"
 #include "zeek/RandTest.h"
 #include "zeek/Val.h"
 #include "zeek/digest.h"
+#include "zeek/telemetry/Counter.h"
+#include "zeek/telemetry/Gauge.h"
+#include "zeek/telemetry/Histogram.h"
 
-namespace broker { class data; }
+namespace broker
+	{
+class data;
+	}
 
-ZEEK_FORWARD_DECLARE_NAMESPACED(BloomFilter, zeek, probabilistic);
-ZEEK_FORWARD_DECLARE_NAMESPACED(CardinalityCounter, zeek, probabilistic, detail);
+namespace zeek
+	{
 
-namespace zeek {
+namespace probabilistic
+	{
+class BloomFilter;
+	}
+namespace probabilistic::detail
+	{
+class CardinalityCounter;
+	}
 
 class OpaqueVal;
 using OpaqueValPtr = IntrusivePtr<OpaqueVal>;
@@ -25,12 +41,13 @@ class BloomFilterVal;
 using BloomFilterValPtr = IntrusivePtr<BloomFilterVal>;
 
 /**
-  * Singleton that registers all available all available types of opaque
-  * values. This faciliates their serialization into Broker values.
-  */
-class OpaqueMgr {
+ * Singleton that registers all available all available types of opaque
+ * values. This faciliates their serialization into Broker values.
+ */
+class OpaqueMgr
+	{
 public:
-	using Factory = OpaqueValPtr ();
+	using Factory = OpaqueValPtr();
 
 	/**
 	 * Return's a unique ID for the type of an opaque value.
@@ -63,27 +80,26 @@ public:
 	 * Internal helper class to register an OpaqueVal-derived classes
 	 * with the manager.
 	 */
-	template<class T>
-	class Register {
+	template <class T> class Register
+		{
 	public:
-		Register(const char* id)
-			{ OpaqueMgr::mgr()->_types.emplace(id, &T::OpaqueInstantiate); }
-	};
+		Register(const char* id) { OpaqueMgr::mgr()->_types.emplace(id, &T::OpaqueInstantiate); }
+		};
 
 private:
 	std::unordered_map<std::string, Factory*> _types;
-};
+	};
 
 /** Macro to insert into an OpaqueVal-derived class's declaration. */
-#define DECLARE_OPAQUE_VALUE(T)                            \
-	friend class zeek::OpaqueMgr::Register<T>; \
-    friend zeek::IntrusivePtr<T> zeek::make_intrusive<T>();            \
-    broker::expected<broker::data> DoSerialize() const override;             \
-    bool DoUnserialize(const broker::data& data) override; \
-    const char* OpaqueName() const override { return #T; } \
-    static zeek::OpaqueValPtr OpaqueInstantiate() { return zeek::make_intrusive<T>(); }
+#define DECLARE_OPAQUE_VALUE(T)                                                                    \
+	friend class zeek::OpaqueMgr::Register<T>;                                                     \
+	friend zeek::IntrusivePtr<T> zeek::make_intrusive<T>();                                        \
+	broker::expected<broker::data> DoSerialize() const override;                                   \
+	bool DoUnserialize(const broker::data& data) override;                                         \
+	const char* OpaqueName() const override { return #T; }                                         \
+	static zeek::OpaqueValPtr OpaqueInstantiate() { return zeek::make_intrusive<T>(); }
 
-#define __OPAQUE_MERGE(a, b) a ## b
+#define __OPAQUE_MERGE(a, b) a##b
 #define __OPAQUE_ID(x) __OPAQUE_MERGE(_opaque, x)
 
 /** Macro to insert into an OpaqueVal-derived class's implementation file. */
@@ -94,10 +110,9 @@ private:
  * completely internally, with no further script-level operators provided
  * (other than bif functions). See OpaqueVal.h for derived classes.
  */
-class OpaqueVal : public Val {
+class OpaqueVal : public Val
+	{
 public:
-	[[deprecated("Remove in v4.1.  Construct from IntrusivePtr instead.")]]
-	explicit OpaqueVal(OpaqueType* t);
 	explicit OpaqueVal(OpaqueTypePtr t);
 	~OpaqueVal() override;
 
@@ -120,7 +135,6 @@ public:
 protected:
 	friend class Val;
 	friend class OpaqueMgr;
-	OpaqueVal() { }
 
 	/**
 	 * Must be overridden to provide a serialized version of the derived
@@ -164,9 +178,10 @@ protected:
 	 * during unserialization. Returns the type at reference count +1.
 	 */
 	static TypePtr UnserializeType(const broker::data& data);
-};
+	};
 
-class HashVal : public OpaqueVal {
+class HashVal : public OpaqueVal
+	{
 public:
 	template <class T>
 	static void digest_all(detail::HashAlgorithm alg, const T& vlist, u_char* result)
@@ -188,10 +203,6 @@ protected:
 	static void digest_one(EVP_MD_CTX* h, const Val* v);
 	static void digest_one(EVP_MD_CTX* h, const ValPtr& v);
 
-	HashVal()	{ valid = false; }
-
-	[[deprecated("Remove in v4.1. Construct from IntrusivePtr instead.")]]
-	explicit HashVal(OpaqueType* t);
 	explicit HashVal(OpaqueTypePtr t);
 
 	virtual bool DoInit();
@@ -201,17 +212,18 @@ protected:
 private:
 	// This flag exists because Get() can only be called once.
 	bool valid;
-};
+	};
 
-class MD5Val : public HashVal {
+class MD5Val : public HashVal
+	{
 public:
-	template <class T>
-	static void digest(const T& vlist, u_char result[MD5_DIGEST_LENGTH])
-		{ digest_all(detail::Hash_MD5, vlist, result); }
+	template <class T> static void digest(const T& vlist, u_char result[MD5_DIGEST_LENGTH])
+		{
+		digest_all(detail::Hash_MD5, vlist, result);
+		}
 
 	template <class T>
-	static void hmac(const T& vlist,
-	                 u_char key[MD5_DIGEST_LENGTH],
+	static void hmac(const T& vlist, u_char key[MD5_DIGEST_LENGTH],
 	                 u_char result[MD5_DIGEST_LENGTH])
 		{
 		digest(vlist, result);
@@ -236,14 +248,20 @@ protected:
 
 	DECLARE_OPAQUE_VALUE(MD5Val)
 private:
+#if ( OPENSSL_VERSION_NUMBER < 0x30000000L ) || defined(LIBRESSL_VERSION_NUMBER)
 	EVP_MD_CTX* ctx;
-};
+#else
+	MD5_CTX ctx;
+#endif
+	};
 
-class SHA1Val : public HashVal {
+class SHA1Val : public HashVal
+	{
 public:
-	template <class T>
-	static void digest(const T& vlist, u_char result[SHA_DIGEST_LENGTH])
-		{ digest_all(detail::Hash_SHA1, vlist, result); }
+	template <class T> static void digest(const T& vlist, u_char result[SHA_DIGEST_LENGTH])
+		{
+		digest_all(detail::Hash_SHA1, vlist, result);
+		}
 
 	SHA1Val();
 	~SHA1Val();
@@ -259,14 +277,20 @@ protected:
 
 	DECLARE_OPAQUE_VALUE(SHA1Val)
 private:
+#if ( OPENSSL_VERSION_NUMBER < 0x30000000L ) || defined(LIBRESSL_VERSION_NUMBER)
 	EVP_MD_CTX* ctx;
-};
+#else
+	SHA_CTX ctx;
+#endif
+	};
 
-class SHA256Val : public HashVal {
+class SHA256Val : public HashVal
+	{
 public:
-	template <class T>
-	static void digest(const T& vlist, u_char result[SHA256_DIGEST_LENGTH])
-		{ digest_all(detail::Hash_SHA256, vlist, result); }
+	template <class T> static void digest(const T& vlist, u_char result[SHA256_DIGEST_LENGTH])
+		{
+		digest_all(detail::Hash_SHA256, vlist, result);
+		}
 
 	SHA256Val();
 	~SHA256Val();
@@ -282,16 +306,20 @@ protected:
 
 	DECLARE_OPAQUE_VALUE(SHA256Val)
 private:
+#if ( OPENSSL_VERSION_NUMBER < 0x30000000L ) || defined(LIBRESSL_VERSION_NUMBER)
 	EVP_MD_CTX* ctx;
-};
+#else
+	SHA256_CTX ctx;
+#endif
+	};
 
-class EntropyVal : public OpaqueVal {
+class EntropyVal : public OpaqueVal
+	{
 public:
 	EntropyVal();
 
 	bool Feed(const void* data, size_t size);
-	bool Get(double *r_ent, double *r_chisq, double *r_mean,
-		 double *r_montepicalc, double *r_scc);
+	bool Get(double* r_ent, double* r_chisq, double* r_mean, double* r_montepicalc, double* r_scc);
 
 protected:
 	friend class Val;
@@ -299,28 +327,29 @@ protected:
 	DECLARE_OPAQUE_VALUE(EntropyVal)
 private:
 	detail::RandTest state;
-};
+	};
 
-class BloomFilterVal : public OpaqueVal {
+class BloomFilterVal : public OpaqueVal
+	{
 public:
 	explicit BloomFilterVal(probabilistic::BloomFilter* bf);
 	~BloomFilterVal() override;
 
 	ValPtr DoClone(CloneState* state) override;
 
-	const TypePtr& Type() const
-		{ return type; }
+	const TypePtr& Type() const { return type; }
 
 	bool Typify(TypePtr type);
 
 	void Add(const Val* val);
+	bool Decrement(const Val* val);
 	size_t Count(const Val* val) const;
 	void Clear();
 	bool Empty() const;
 	std::string InternalState() const;
 
-	static BloomFilterValPtr Merge(const BloomFilterVal* x,
-	                               const BloomFilterVal* y);
+	static BloomFilterValPtr Merge(const BloomFilterVal* x, const BloomFilterVal* y);
+	static BloomFilterValPtr Intersect(const BloomFilterVal* x, const BloomFilterVal* y);
 
 protected:
 	friend class Val;
@@ -335,10 +364,10 @@ private:
 	TypePtr type;
 	detail::CompositeHash* hash;
 	probabilistic::BloomFilter* bloom_filter;
-};
+	};
 
-
-class CardinalityVal : public OpaqueVal {
+class CardinalityVal : public OpaqueVal
+	{
 public:
 	explicit CardinalityVal(probabilistic::detail::CardinalityCounter*);
 	~CardinalityVal() override;
@@ -347,12 +376,11 @@ public:
 
 	void Add(const Val* val);
 
-	const TypePtr& Type() const
-		{ return type; }
+	const TypePtr& Type() const { return type; }
 
 	bool Typify(TypePtr type);
 
-	probabilistic::detail::CardinalityCounter* Get()	{ return c; };
+	probabilistic::detail::CardinalityCounter* Get() { return c; };
 
 protected:
 	CardinalityVal();
@@ -362,33 +390,77 @@ private:
 	TypePtr type;
 	detail::CompositeHash* hash;
 	probabilistic::detail::CardinalityCounter* c;
-};
+	};
 
-class ParaglobVal : public OpaqueVal {
+class ParaglobVal : public OpaqueVal
+	{
 public:
 	explicit ParaglobVal(std::unique_ptr<paraglob::Paraglob> p);
-	VectorValPtr Get(StringVal* &pattern);
+	VectorValPtr Get(StringVal*& pattern);
 	ValPtr DoClone(CloneState* state) override;
 	bool operator==(const ParaglobVal& other) const;
 
 protected:
-	ParaglobVal() : OpaqueVal(paraglob_type) {}
+	ParaglobVal() : OpaqueVal(paraglob_type) { }
 
 	DECLARE_OPAQUE_VALUE(ParaglobVal)
 
 private:
 	std::unique_ptr<paraglob::Paraglob> internal_paraglob;
-};
+	};
 
-} // namespace zeek
+/**
+ * Base class for metric handles. Handle types are not serializable.
+ */
+class TelemetryVal : public OpaqueVal
+	{
+protected:
+	explicit TelemetryVal(telemetry::IntCounter);
+	explicit TelemetryVal(telemetry::IntCounterFamily);
+	explicit TelemetryVal(telemetry::DblCounter);
+	explicit TelemetryVal(telemetry::DblCounterFamily);
+	explicit TelemetryVal(telemetry::IntGauge);
+	explicit TelemetryVal(telemetry::IntGaugeFamily);
+	explicit TelemetryVal(telemetry::DblGauge);
+	explicit TelemetryVal(telemetry::DblGaugeFamily);
+	explicit TelemetryVal(telemetry::IntHistogram);
+	explicit TelemetryVal(telemetry::IntHistogramFamily);
+	explicit TelemetryVal(telemetry::DblHistogram);
+	explicit TelemetryVal(telemetry::DblHistogramFamily);
 
-using OpaqueMgr [[deprecated("Remove in v4.1. Use zeek::OpaqueMgr instead.")]] = zeek::OpaqueMgr;
-using OpaqueVal [[deprecated("Remove in v4.1. Use zeek::OpaqueVal instead.")]] = zeek::OpaqueVal;
-using HashVal [[deprecated("Remove in v4.1. Use zeek::HashVal instead.")]] = zeek::HashVal;
-using MD5Val [[deprecated("Remove in v4.1. Use zeek::MD5Val instead.")]] = zeek::MD5Val;
-using SHA1Val [[deprecated("Remove in v4.1. Use zeek::SHA1Val instead.")]] = zeek::SHA1Val;
-using SHA256Val [[deprecated("Remove in v4.1. Use zeek::SHA256Val instead.")]] = zeek::SHA256Val;
-using EntropyVal [[deprecated("Remove in v4.1. Use zeek::EntropyVal instead.")]] = zeek::EntropyVal;
-using BloomFilterVal [[deprecated("Remove in v4.1. Use zeek::BloomFilterVal instead.")]] = zeek::BloomFilterVal;
-using CardinalityVal [[deprecated("Remove in v4.1. Use zeek::CardinalityVal instead.")]] = zeek::CardinalityVal;
-using ParaglobVal [[deprecated("Remove in v4.1. Use zeek::ParaglobVal instead.")]] = zeek::ParaglobVal;
+	broker::expected<broker::data> DoSerialize() const override;
+	bool DoUnserialize(const broker::data& data) override;
+	};
+
+template <class Handle> class TelemetryValImpl : public TelemetryVal
+	{
+public:
+	using HandleType = Handle;
+
+	explicit TelemetryValImpl(Handle hdl) : TelemetryVal(hdl), hdl(hdl) { }
+
+	Handle GetHandle() const noexcept { return hdl; }
+
+protected:
+	ValPtr DoClone(CloneState*) override { return make_intrusive<TelemetryValImpl>(hdl); }
+
+	const char* OpaqueName() const override { return Handle::OpaqueName; }
+
+private:
+	Handle hdl;
+	};
+
+using IntCounterMetricVal = TelemetryValImpl<telemetry::IntCounter>;
+using IntCounterMetricFamilyVal = TelemetryValImpl<telemetry::IntCounterFamily>;
+using DblCounterMetricVal = TelemetryValImpl<telemetry::DblCounter>;
+using DblCounterMetricFamilyVal = TelemetryValImpl<telemetry::DblCounterFamily>;
+using IntGaugeMetricVal = TelemetryValImpl<telemetry::IntGauge>;
+using IntGaugeMetricFamilyVal = TelemetryValImpl<telemetry::IntGaugeFamily>;
+using DblGaugeMetricVal = TelemetryValImpl<telemetry::DblGauge>;
+using DblGaugeMetricFamilyVal = TelemetryValImpl<telemetry::DblGaugeFamily>;
+using IntHistogramMetricVal = TelemetryValImpl<telemetry::IntHistogram>;
+using IntHistogramMetricFamilyVal = TelemetryValImpl<telemetry::IntHistogramFamily>;
+using DblHistogramMetricVal = TelemetryValImpl<telemetry::DblHistogram>;
+using DblHistogramMetricFamilyVal = TelemetryValImpl<telemetry::DblHistogramFamily>;
+
+	} // namespace zeek
