@@ -3,26 +3,29 @@
 #include <list>
 #include <utility>
 
-#include "zeek/threading/MsgThread.h"
 #include "zeek/Timer.h"
+#include "zeek/threading/MsgThread.h"
 
-namespace zeek {
-namespace threading {
-namespace detail {
+namespace zeek
+	{
+namespace threading
+	{
+namespace detail
+	{
 
-class HeartbeatTimer final : public zeek::detail::Timer {
+class HeartbeatTimer final : public zeek::detail::Timer
+	{
 public:
-	HeartbeatTimer(double t) : zeek::detail::Timer(t, zeek::detail::TIMER_THREAD_HEARTBEAT) {}
-	virtual ~HeartbeatTimer() {}
+	HeartbeatTimer(double t) : zeek::detail::Timer(t, zeek::detail::TIMER_THREAD_HEARTBEAT) { }
+	virtual ~HeartbeatTimer() { }
 
 	void Dispatch(double t, bool is_expire) override;
 
 protected:
-
 	void Init();
-};
+	};
 
-} // namespace detail
+	} // namespace detail
 
 /**
  * The thread manager coordinates all child threads. Once a BasicThread is
@@ -32,10 +35,10 @@ protected:
  * In addition to basic threads, the manager also provides additional
  * functionality specific to MsgThread instances. In particular, it polls
  * their outgoing message queue on a regular basis and feeds data sent into
- * the rest of Bro. It also triggers the regular heartbeats.
+ * the rest of Zeek. It also triggers the regular heartbeats.
  */
 class Manager
-{
+	{
 public:
 	/**
 	 * Constructor. Only a single instance of the manager must be
@@ -60,9 +63,9 @@ public:
 	 * Returns True if we are currently in Terminate() waiting for
 	 * threads to exit.
 	 */
-	bool Terminating() const	{ return terminating; }
+	bool Terminating() const { return terminating; }
 
-	typedef std::list<std::pair<std::string, MsgThread::Stats> > msg_stats_list;
+	using msg_stats_list = std::list<std::pair<std::string, MsgThread::Stats>>;
 
 	/**
 	 * Returns statistics from all current MsgThread instances.
@@ -101,7 +104,8 @@ public:
 	 * @param vals Values passed to the event
 	 * @returns True on success false on failure.
 	 */
-	bool SendEvent(MsgThread* thread, const std::string& name, const int num_vals, Value* *vals) const;
+	bool SendEvent(MsgThread* thread, const std::string& name, const int num_vals,
+	               Value** vals) const;
 
 protected:
 	friend class BasicThread;
@@ -139,22 +143,22 @@ protected:
 	void StartHeartbeatTimer();
 
 private:
-	typedef std::list<BasicThread*> all_thread_list;
+	using all_thread_list = std::list<BasicThread*>;
 	all_thread_list all_threads;
 
-	typedef std::list<MsgThread*> msg_thread_list;
+	using msg_thread_list = std::list<MsgThread*>;
 	msg_thread_list msg_threads;
 
-	bool did_process;	// True if the last Process() found some work to do.
-	double next_beat;	// Timestamp when the next heartbeat will be sent.
-	bool terminating;	// True if we are in Terminate().
+	bool did_process; // True if the last Process() found some work to do.
+	double next_beat; // Timestamp when the next heartbeat will be sent.
+	bool terminating; // True if we are in Terminate().
 
 	msg_stats_list stats;
 
 	bool heartbeat_timer_running = false;
-};
+	};
 
-} // namespace threading
+	} // namespace threading
 
 /**
  * A singleton instance of the thread manager. All methods must only be
@@ -162,17 +166,4 @@ private:
  */
 extern threading::Manager* thread_mgr;
 
-} // namespace zeek
-
-extern zeek::threading::Manager*& thread_mgr [[deprecated("Remove in v4.1. Use zeek::thread_mgr.")]];
-
-namespace threading {
-
-using Manager [[deprecated("Remove in v4.1. Use zeek::threading::Manager.")]] = zeek::threading::Manager;
-
-namespace detail {
-
-using HeartbeatTimer [[deprecated("Remove in v4.1. Use zeek::threading::detail::HeartbeatTimer.")]] = zeek::threading::detail::HeartbeatTimer;
-
-} // namespace detail
-} // namespace threading
+	} // namespace zeek
