@@ -99,13 +99,13 @@
 #define SIN_LEN
 
 /* The size of `long int', as computed by sizeof. */
-#define SIZEOF_LONG_INT 4
+#define SIZEOF_LONG_INT 8
 
 /* The size of `long long', as computed by sizeof. */
 #define SIZEOF_LONG_LONG 8
 
 /* The size of `void *', as computed by sizeof. */
-#define SIZEOF_VOID_P 4
+#define SIZEOF_VOID_P 8
 
 /* should we declare syslog() and openlog() */
 /* #undef SYSLOG_INT */
@@ -135,12 +135,12 @@
 /* #undef USE_ELASTICSEARCH */
 
 /* Version number of package */
-#define VERSION "5.0.2"
+#define VERSION "5.0.3"
 
 // Zeek version number.
 // This is the result of (major * 10000 + minor * 100 + patch)
 // For example, 3.1.2 becomes 30102.
-#define ZEEK_VERSION_NUMBER 50002
+#define ZEEK_VERSION_NUMBER 50003
 
 /* whether words are stored with the most significant byte first */
 /* #undef WORDS_BIGENDIAN */
@@ -235,7 +235,7 @@
 #define HAVE_IP6_EXT
 
 /* String with host architecture (e.g., "linux-x86_64") */
-#define HOST_ARCHITECTURE "openbsd-i386"
+#define HOST_ARCHITECTURE "openbsd-arm64"
 
 /* String with extension of dynamic libraries (e.g., ".so") */
 #define DYNAMIC_PLUGIN_SUFFIX ".so"
@@ -246,7 +246,7 @@
 #endif
 
 /* A C function that has the Zeek version encoded into its name. */
-#define BRO_VERSION_FUNCTION bro_version_5_0_2_plugin_7
+#define BRO_VERSION_FUNCTION bro_version_5_0_3_plugin_7
 #ifdef __cplusplus
 extern "C" {
 #endif
